@@ -12,7 +12,7 @@ class Ptrms:
         self.sample_end = sample_end
         self.frame = pd.DataFrame
         self.errors = []
-        self.threshold = int(threshold)
+        self.threshold = threshold
         self.dif = pd.DataFrame
         self.out_path = lambda x: os.path.join(
             os.path.dirname(self.file.name), x
@@ -27,7 +27,7 @@ class Ptrms:
             try:
                 self.frame = pd.read_excel(self.file)
             except pd.errors.EmptyDataError:
-                self.seek(0)
+                self.file.seek(0)
                 self._load(sep=None, excel=True)
         else:
             try:
@@ -54,27 +54,33 @@ class Ptrms:
 
     def extract_windows(self):
         ref_window_stats = (
-            self.frame.loc[int(self.ref_start) - 1: int(self.ref_end)]
+            self.frame.loc[int(self.ref_start) - 1: int(self.ref_end)+1]
                 .drop(columns=["Cycle"], errors="ignore")
                 .describe()
-        )
+        ).transpose()
         sample_window_stats = (
-            self.frame.loc[int(self.sample_start) - 1: int(self.sample_end)]
+            self.frame.loc[int(self.sample_start) - 1: int(self.sample_end)+1]
                 .drop(columns=["Cycle"], errors="ignore")
                 .describe()
-        )
+        ).transpose()
 
-        self.dif = sample_window_stats.transpose().sub(ref_window_stats.transpose())
+        self.dif = sample_window_stats.sub(ref_window_stats)
+        self.dif = self.dif.drop(columns=['std'], errors='ignore')
+        self.dif = self.dif.add_prefix('Difference ')
+        sample_window_stats = sample_window_stats.add_prefix('Sample ')
+        ref_window_stats = ref_window_stats.add_prefix('Reference ')
+        self.dif = pd.concat([self.dif, sample_window_stats, ref_window_stats], axis=1)
         out_path = self.out_path(f"extracted_window.xlsx")
         try:
             self.dif.to_excel(out_path)
         except PermissionError as e:
             self.errors.append('Unable to write window data, the file may be open')
         if self.threshold:
+            self.threshold = int(self.threshold)
             self.threshold_extract()
 
     def threshold_extract(self):
-        rows = self.dif[self.dif['max'] > self.threshold].index
+        rows = self.dif[self.dif['max'] >= self.threshold].index
         thresh_data = self.frame[rows]
         out_path = self.out_path(f'Extracted Threshold {self.threshold}.xlsx')
         try:
